/* -------------------------------------------------------
                         blinky.c

     Demoprogramm fuer erstes Lebenszeichen des MCU

     MCU   :  STM8S103F3
     Takt  :  interner Takt 16 MHz

     03.02.2020  R. Seelig
   ------------------------------------------------------ */

/*
##################################################################
                      STM8S103F3P6 Pinout
##################################################################


                            ------------
UART1_CK / TIM2_CH1 / PD4  |  1     20  |  PD3 / AIN4 / TIM2_CH2 / ADC_ETR
    UART1_TX / AIN5 / PD5  |  2     19  |  PD2 / AIN3
    UART1_RX / AIN6 / PD6  |  3     18  |  PD1 / SWIM
                     NRST  |  4     17  |  PC7 / SPI_MISO
              OSCIN / PA1  |  5     16  |  PC6 / SPI_MOSI
             OSCOUT / PA2  |  6     15  |  PC5 / SPI_CLK
                Vss (GND)  |  7     14  |  PC4 / TIM1_CH4 / CLK_CCO / AIN2
                VCAP (*1)  |  8     13  |  PC3 / TIM1_CH3 /
                Vdd (+Ub)  |  9     12  |  PB4 / I2C_SCL
           TIM2_CH3 / PA3  | 10     11  |  PB5 / I2C_SDA
                            -----------

*1 :  Ist mit min. 1uF gegen GND zu verschalten

*/


#include "stm8s.h"
#include "stm8_init.h"
#include "stm8_gpio.h"

#define led1_init()    PB5_output_init()
#define led1_set()     PB5_set()
#define led1_clr()     PB5_clr()


#define blinkspeed      1000

/* -------------------------------------------------------
                               main
   ------------------------------------------------------- */
int main(void)
{

  sysclock_init(0);                     // Initialisieren mit internem Takt
  delay(100);

  led1_init();

  while(1)
  {
    led1_clr();
    delay(blinkspeed);
    led1_set();
    delay(blinkspeed);
  }
}

