/* -------------------------------------------------------
                           hx1838_d.h

     Header fuer Softwaremodul zum HX1838 IR-Receiver

     Belegt zur Auswertung des Receivers Timer1, IR-
     Receiver loest am angeschlossenen Pin einen
     externen Interrupt aus

     MCU   :  STM8S103F3
     Takt  :  interner Takt 16 MHz

     26.07.2017  R. Seelig
   ------------------------------------------------------ */

#ifndef in_hx1838_d
  #define in_hx1838_d

  #include "stm8s.h"
  #include "stm8_init.h"
  #include "stm8_gpio.h"


  // Datenpin des Receivers ist an Port A , Bit 3 angeschlossen

  #define ir_int_enable()    PD_CR2 |= (1 << PD4)                             // PD4 Eingang interruptfaehig
  #define ir_int_disable()   PD_CR2 &= ~(1 << PD4)                            // PD4 Eingang nicht interruptfaehig
  #define is_irin()          is_PD4()

  #define ir_input_init()    { PD4_input_init(); ir_int_enable(); }



  #define tim1_getvalue()    ( (uint16_t) ( (TIM1_CNTRH << 8) | TIM1_CNTRL ))
  #define tim1_clr()         { TIM1_EGR |= 1;  tim1_init(); }                 // TIM1_EGR Bit0: (UG) update generation = Reset des Timers


  extern volatile uint16_t  ir_code;                                          // Code des letzten eingegangenen 16-Bit Wertes
  extern volatile uint8_t   ir_newflag;                                       // zeigt an, ob ein neuer Wert eingegangen ist


  // ISR fuer PortD und die dazugehoerende Init-Funktion
  void PortD_extint(void) __interrupt(_GPIOD_VECT);
  volatile void portdint_init(void);


#endif
