/* -------------------------------------------------------
                        seg7anz_v3.h

     Headerdatei fuer max. 8-stellige 7-Segmentanzeige
     mittels zwei 74HC595 Schieberegistern

     Anmerkung: die Anzeigesegmente des Moduls werden
                gemultiplext werden, da nur
                2 Schieberegister verwendet werden.
                SR sind kaskadiert, zuerst ist der
                Datenwert der Ziffer, danach die
                Multiplexstelle auszuschieben.

                Zum Multiplexen wird Timer als
                interruptbetriebene Taktquelle
                eingesetzt.

                Dieser Interrupt zaehlt zusaetzlich die
                globalen Variablen tim2_sek und tim2_zsek
                durch.

     Hardware : 7-Segment LED Anzeigen
                2 Stck. SN74HC595 Schiebberegister
                               oder
                Chinamodul "4-Bit LED Digital Tube Modul"

     MCU       : STM8S003 / STM8S103 / STM8S105
     Takt      : interner Takt 16 MHz

     03.02.2020  R. Seelig
   ------------------------------------------------------ */

/*
   Anschluesse:
 ------------------------------------------------------
   Pinbelegung:

   4 Bit LED Digital Tube Module                 STM8S103F
   -------------------------------------------------------

       (shift-clock)   Sclk   -------------------- PC6
       (strobe-clock)  Rclk   -------------------- PC7
       (ser. data in)  Dio    -------------------- PC5
       (+Ub)           Vcc
                       Gnd

   Segmentbelegung der 7-Segmentanzeige:

       a
      ---
   f | g | b            Segment | dp |  g  |  f  |  e  |  d  |  c  |  b  |  a  |
      ---               --------------------------------------------------------
   e |   | c            Bit-Nr. |  7 |  6  |  5  |  4  |  3  |  2  |  1  |  0  |
      ---
       d

*/

#ifndef in_seg7anz_v2
  #define in_seg7anz_v2

  #include "stm8s.h"
  #include "stm8_init.h"
  #include "stm8_gpio.h"


  #define seg7_common     1                  // Flag fuer Auswahl des 7-Segment Typs
                                             //    0 : 7-Segment mit gemeinsamer Kathode
                                             //    1 : 7-Segment mit gemeinsamer Anode

  //  Anschlusspins des Schieberegisters
  #define srdata_init()       PC5_output_init()
  #define srdata_set()        PC5_set()
  #define srdata_clr()        PC5_clr()

  #define srstrobe_init()     PC7_output_init()
  #define srstrobe_set()      PC7_set()
  #define srstrobe_clr()      PC7_clr()

  #define srclock_init()      PC6_output_init()
  #define srclock_set()       PC6_set()
  #define srclock_clr()       PC6_clr()

  extern uint8_t  seg7_4digit[8];
  extern uint8_t  led7sbmp[16];

  extern uint8_t  tim2_sek, tim2_zsek;


  /* ----------------------------------------------------------
     Prototypen
     ---------------------------------------------------------- */

  void digit4_delay(void);
  void digit4_ckpuls(void);
  void digit4_stpuls(void);
  void digit4_outbyte(uint8_t value);
  void digit4_setdez(uint32_t value, uint8_t nonull);
  void digit4_setdez8bit(uint8_t value, uint8_t pos);
  void digit4_sethex(uint32_t value, uint8_t nonull);
  void digit4_setall8(uint8_t c7, uint8_t c6, uint8_t c5, uint8_t c4,
                      uint8_t c3, uint8_t c2, uint8_t c1, uint8_t c0);
  void digit4_setall4(uint8_t c3, uint8_t c2, uint8_t c1, uint8_t c0);
  void digit4_setdp(char pos);
  void digit4_clrdp(char pos);
  void digit4_clr(void);
  void digit4_init(void);

  void tim2_init(void);
  void tim2_ovf(void) __interrupt(13);

#endif
