/* ------------------------------------------------
                      tftmono_demo.c

   Demoprogramm zur Verwendung mit
     - SSD1306 Displays (I2C und SPI Interface)
     - Nokia 5110 Displays (84x48)

   Displaytyp einstellbar in tftmono.h

   MCU   :  STM8S103 / S105
   Takt  :  externer Takt 16 MHz

   04.02.2020 by R. Seelig

  -------------------------------------------------- */

#include <stdlib.h>                             // fuer abs()
#include "stm8s.h"
#include "stm8_init.h"
#include "stm8_gpio.h"

#include "tftmono.h"
#include "my_printf.h"

#include "girl2.h"

#define printf       my_printf


/* --------------------------------------------------------
   putchar

   wird von my-printf / printf aufgerufen und hier muss
   eine Zeichenausgabefunktion angegeben sein, auf das
   printf dann schreibt !
   -------------------------------------------------------- */
void my_putchar(uint8_t ch)
{
  lcd_putchar(ch);
}


/* ------------------------------------------------------------------------
                                    MAIN
   ------------------------------------------------------------------------ */

int main(void)
{
  int i;

  sysclock_init(0);                     // zuerst System fuer internen Takt

  lcd_init();
  lcd_enable();
  lcd_init();
  lcd_enable();
  clrscr();

  textsize= 0;

  fb_init(84, 6);
  while(1)
  {
    clrscr();
    setfont(fnt8x8);
    gotoxy(1,1);
    printf("Mono-TFT\n\r");
    setfont(fnt8x8);
    delay(2000);
    clrscr();

    fb_clear();
    fb_outtextxy(1,5, 0, "Hallo Welt");
    fb_outtextxy(24,13, 0, "fuer");

    #ifdef __stm8s105k4__
      fb_outtextxy(9,25, 0,"STM8S105");
    #else
      fb_outtextxy(9,25, 0,"STM8S103");
    #endif

    fb_show((_xres/2)-42, 0);
    delay(2000);

    fb_clear();
    fillcircle(42,20, 17, 1);
    line(0,0, 83,39, 2);
    fb_show((_xres/2)-42, 0);
    delay(2000);

    clrscr();
    #if (ssd1306 == 1)
      showimage((_xres/2)-42, 2, &girl2_image[0], 1);           // schwarzes Display, helle Schrift
    #else
      showimage((_xres/2)-42, 2, &girl2_image[0], 2);           // helles Display, schwarze Schrift
    #endif
    delay(2000);

  }
}
